You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@river.apache.org by pe...@apache.org on 2013/01/02 06:21:08 UTC

svn commit: r1427655 [22/35] - in /river/jtsk/skunk/qa_refactor/trunk/qa: ./ doc/ src/com/sun/jini/qa/harness/ src/com/sun/jini/test/impl/discoverymanager/ src/com/sun/jini/test/impl/discoveryproviders/ src/com/sun/jini/test/impl/end2end/e2etest/ src/c...

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/constraint/coreconstraint/util/AbstractConstructorsTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/constraint/coreconstraint/util/AbstractConstructorsTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/constraint/coreconstraint/util/AbstractConstructorsTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/constraint/coreconstraint/util/AbstractConstructorsTest.java Wed Jan  2 05:20:52 2013
@@ -24,16 +24,17 @@ import com.sun.jini.qa.harness.TestExcep
 
 // com.sun.jini.qa.harness
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 
 // java.util
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 
 
 /**
  * Abstract class to test constructors.
  */
-abstract public class AbstractConstructorsTest extends QATest {
+abstract public class AbstractConstructorsTest extends QATestEnvironment implements Test {
     protected QAConfig config;
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/constraint/coreconstraint/util/AbstractImmutableSetTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/constraint/coreconstraint/util/AbstractImmutableSetTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/constraint/coreconstraint/util/AbstractImmutableSetTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/constraint/coreconstraint/util/AbstractImmutableSetTest.java Wed Jan  2 05:20:52 2013
@@ -20,13 +20,14 @@ package com.sun.jini.test.spec.constrain
 import java.util.logging.Level;
 
 // com.sun.jini.qa
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import com.sun.jini.qa.harness.QAConfig;
 
 // com.sun.jini.qa.harness
 import com.sun.jini.qa.harness.QAConfig; // base class for QAConfig
 
 // java.util
+import com.sun.jini.qa.harness.Test;
 import java.util.logging.Level;
 import java.util.Set;
 
@@ -43,7 +44,7 @@ import java.util.Set;
  *
  * </pre>
  */
-abstract public class AbstractImmutableSetTest extends QATest {
+abstract public class AbstractImmutableSetTest extends QATestEnvironment implements Test {
     protected QAConfig config;
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/constraint/coreconstraint/util/AbstractSimpleTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/constraint/coreconstraint/util/AbstractSimpleTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/constraint/coreconstraint/util/AbstractSimpleTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/constraint/coreconstraint/util/AbstractSimpleTest.java Wed Jan  2 05:20:52 2013
@@ -20,11 +20,12 @@ package com.sun.jini.test.spec.constrain
 import java.util.logging.Level;
 
 // com.sun.jini.qa
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import com.sun.jini.qa.harness.QAConfig;
 
 // com.sun.jini.qa.harness
 import com.sun.jini.qa.harness.QAConfig; // base class for QAConfig
+import com.sun.jini.qa.harness.Test;
 import com.sun.jini.qa.harness.TestException;
 
 // java.util
@@ -94,7 +95,7 @@ import net.jini.core.constraint.ServerMi
  *
  * </pre>
  */
-abstract public class AbstractSimpleTest extends QATest {
+abstract public class AbstractSimpleTest extends QATestEnvironment implements Test {
     QAConfig config;
 
     /**

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/AbstractBaseTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/AbstractBaseTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/AddNewDiscoveryChangeListener.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/AddNewDiscoveryChangeListener.java Wed Jan  2 05:20:52 2013
@@ -19,6 +19,7 @@
 package com.sun.jini.test.spec.discoverymanager;
 
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the <code>addDiscoveryListener</code> method, this class
@@ -56,9 +57,10 @@ public class AddNewDiscoveryChangeListen
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         newListener = new GroupChangeListener();
+        return this;
     }
 
 }//end class AddNewDiscoveryChangeListener

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/AddNewDiscoveryListener.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/AddNewDiscoveryListener.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/AddNewDiscoveryListener.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/AddNewDiscoveryListener.java Wed Jan  2 05:20:52 2013
@@ -80,7 +80,7 @@ public class AddNewDiscoveryListener ext
         super.run();
         logger.log(Level.FINE, "adding a new listener to the "
 		   +"lookup discovery manager ... ");
-        newListener.setLookupsToDiscover(initLookupsToStart,
+        newListener.setLookupsToDiscover(getInitLookupsToStart(),
                                          locatorsToDiscover,
                                          groupsToDiscover);
         discoveryMgr.addDiscoveryListener(newListener);

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/DiscardUnreachable.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/DiscardUnreachable.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/DiscardUnreachable.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/DiscardUnreachable.java Wed Jan  2 05:20:52 2013
@@ -83,7 +83,7 @@ public class DiscardUnreachable extends 
          */
         synchronized(mainListener) {
             logger.log(Level.FINE, "terminating each lookup service ...");
-            /* Stop announcements & destroy all lookups started in setup */
+            /* Stop announcements & destroy all lookups started in construct */
             terminateAllLookups();
             DiscoveryServiceUtil.delayMS(7000);//wait for shutdown complete
             logger.log(Level.FINE, "discarding un-reachable lookup services ...");

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/Discovered.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/Discovered.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/Discovered.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/Discovered.java Wed Jan  2 05:20:52 2013
@@ -23,6 +23,8 @@ import java.util.logging.Level;
 import net.jini.discovery.DiscoveryGroupManagement;
 import net.jini.core.discovery.LookupLocator;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
+import java.util.List;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -70,13 +72,15 @@ public class Discovered extends Abstract
      *         configure the lookup discovery manager to discover
      *  </ul>
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        List initLookupsToStart = getLookupServices().getInitLookupsToStart();
         groupsToDiscover = toGroupsToDiscover(initLookupsToStart,
                                               AbstractBaseTest.MIX);
         locatorsToDiscover = toLocatorsToDiscover(initLookupsToStart,
                                                   AbstractBaseTest.MIX);
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>
@@ -91,6 +95,7 @@ public class Discovered extends Abstract
      */
     public void run() throws Exception {
         logger.log(Level.FINE, "run()");
+        List initLookupsToStart = getLookupServices().getInitLookupsToStart();
         doDiscovery(initLookupsToStart,discoveryMgr,mainListener,
                     locatorsToDiscover,groupsToDiscover);
     }//end run

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/DiscoveredAll.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/DiscoveredAll.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/DiscoveredAll.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/DiscoveredAll.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.spec.discovery
 
 import net.jini.discovery.DiscoveryGroupManagement;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -54,9 +55,10 @@ public class DiscoveredAll extends Disco
      *
      *  Retrieves additional configuration values. 
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         groupsToDiscover = DiscoveryGroupManagement.ALL_GROUPS;
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class DiscoveredAll

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsAddNewDiscoveryChangeListener.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsAddNewDiscoveryChangeListener.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsAddNewDiscoveryChangeListener.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsAddNewDiscoveryChangeListener.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the <code>addDiscoveryListener</code> method, this class
@@ -57,14 +58,15 @@ public class GroupsAddNewDiscoveryChange
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        groupsToDiscover = toGroupsToDiscover(initLookupsToStart,
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        groupsToDiscover = toGroupsToDiscover(getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_GROUP);
         locatorsToDiscover = toLocatorsToDiscover
-                                             (initLookupsToStart,
+                                             (getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_GROUP);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class GroupsAddNewDiscoveryChangeListener
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsAddNewDiscoveryListener.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsAddNewDiscoveryListener.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsAddNewDiscoveryListener.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsAddNewDiscoveryListener.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the <code>addDiscoveryListener</code> method, this class
@@ -56,14 +57,15 @@ public class GroupsAddNewDiscoveryListen
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        groupsToDiscover = toGroupsToDiscover(initLookupsToStart,
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        groupsToDiscover = toGroupsToDiscover(getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_GROUP);
         locatorsToDiscover = toLocatorsToDiscover
-                                             (initLookupsToStart,
+                                             (getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_GROUP);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class GroupsAddNewDiscoveryListener
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsDiscardUnreachable.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsDiscardUnreachable.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsDiscardUnreachable.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsDiscardUnreachable.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 /**
  * With respect to the <code>discard</code> method, this class verifies
  * that the <code>LookupDiscoveryManager</code> utility operates in a manner
@@ -55,14 +56,15 @@ public class GroupsDiscardUnreachable ex
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        groupsToDiscover = toGroupsToDiscover(initLookupsToStart,
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        groupsToDiscover = toGroupsToDiscover(getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_GROUP);
         locatorsToDiscover = toLocatorsToDiscover
-                                             (initLookupsToStart,
+                                             (getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_GROUP);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class GroupsDiscardUnreachable
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsDiscovered.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsDiscovered.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsDiscovered.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsDiscovered.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -53,14 +54,15 @@ public class GroupsDiscovered extends Di
      *
      *  Retrieves additional configuration values. 
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        groupsToDiscover = toGroupsToDiscover(initLookupsToStart,
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        groupsToDiscover = toGroupsToDiscover(getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_GROUP);
         locatorsToDiscover = toLocatorsToDiscover
-                                             (initLookupsToStart,
+                                             (getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_GROUP);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class GroupsDiscovered
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsDiscoveredAll.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsDiscoveredAll.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsDiscoveredAll.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsDiscoveredAll.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -53,12 +54,13 @@ public class GroupsDiscoveredAll extends
      *
      *  Retrieves additional configuration values. 
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         locatorsToDiscover = toLocatorsToDiscover
-                                              (initLookupsToStart,
+                                              (getInitLookupsToStart(),
                                                AbstractBaseTest.ALL_BY_GROUP);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class GroupsDiscoveredAll
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorChange.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorChange.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorChange.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorChange.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -50,14 +51,15 @@ public class GroupsMulticastMonitorChang
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        groupsToDiscover = toGroupsToDiscover(initLookupsToStart,
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        groupsToDiscover = toGroupsToDiscover(getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_GROUP);
         locatorsToDiscover = toLocatorsToDiscover
-                                             (initLookupsToStart,
+                                             (getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_GROUP);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class GroupsMulticastMonitorChange
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorReplace.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorReplace.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorReplace.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorReplace.java Wed Jan  2 05:20:52 2013
@@ -20,7 +20,8 @@ package com.sun.jini.test.spec.discovery
 
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
-import java.util.ArrayList;
+import com.sun.jini.qa.harness.Test;
+import java.util.List;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -56,15 +57,16 @@ public class GroupsMulticastMonitorRepla
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        groupsToDiscover = toGroupsToDiscover(initLookupsToStart,
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        groupsToDiscover = toGroupsToDiscover(getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_GROUP);
         locatorsToDiscover = toLocatorsToDiscover
-                                             (initLookupsToStart,
+                                             (getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_GROUP);
-        nLookupsToReplace = genMap.size();//replace groups on all lookups
-    }//end setup
+        nLookupsToReplace = getGenMap().size();//replace groups on all lookups
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>
@@ -87,11 +89,11 @@ public class GroupsMulticastMonitorRepla
          * maps to change until setLookupsToDiscover returns.
          */
         synchronized(mainListener) {
-            ArrayList locGroupsPairList = null;
+            List locGroupsPairList = null;
             /* Replace current groups with new groups to cause discards */
             if(replacementGroups == null) {//use unique generated groups
                 locGroupsPairList = replaceMemberGroups();
-            } else {//use groups preset in setup
+            } else {//use groups preset in construct
                 locGroupsPairList = replaceMemberGroups(nLookupsToReplace,
                                                         replacementGroups);
             }//endif

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorReplaceAll.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorReplaceAll.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorReplaceAll.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorReplaceAll.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -58,12 +59,13 @@ public class GroupsMulticastMonitorRepla
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         locatorsToDiscover = toLocatorsToDiscover
-                                              (initLookupsToStart,
+                                              (getInitLookupsToStart(),
                                                AbstractBaseTest.ALL_BY_GROUP);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class GroupsMulticastMonitorReplaceAll
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorReplaceNone.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorReplaceNone.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorReplaceNone.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorReplaceNone.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -50,14 +51,15 @@ public class GroupsMulticastMonitorRepla
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        groupsToDiscover = toGroupsToDiscover(initLookupsToStart,
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        groupsToDiscover = toGroupsToDiscover(getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_GROUP);
         locatorsToDiscover = toLocatorsToDiscover
-                                             (initLookupsToStart,
+                                             (getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_GROUP);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class GroupsMulticastMonitorReplaceNone
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorStop.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorStop.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorStop.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorStop.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -65,14 +66,15 @@ public class GroupsMulticastMonitorStop 
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        groupsToDiscover = toGroupsToDiscover(initLookupsToStart,
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        groupsToDiscover = toGroupsToDiscover(getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_GROUP);
         locatorsToDiscover = toLocatorsToDiscover
-                                             (initLookupsToStart,
+                                             (getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_GROUP);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class GroupsMulticastMonitorStop
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsMulticastMonitorTerminate.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -51,14 +52,15 @@ public class GroupsMulticastMonitorTermi
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        groupsToDiscover = toGroupsToDiscover(initLookupsToStart,
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        groupsToDiscover = toGroupsToDiscover(getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_GROUP);
         locatorsToDiscover = toLocatorsToDiscover
-                                             (initLookupsToStart,
+                                             (getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_GROUP);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class MulticastMonitorTerminate
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsSetGroupsReplaceAll.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsSetGroupsReplaceAll.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsSetGroupsReplaceAll.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/GroupsSetGroupsReplaceAll.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.spec.discovery
 
 import java.util.Map;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the <code>setGroups</code> method, this class verifies
@@ -57,14 +58,15 @@ public class GroupsSetGroupsReplaceAll e
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        groupsToDiscover = toGroupsToDiscover(initLookupsToStart,
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        groupsToDiscover = toGroupsToDiscover(getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_GROUP);
         locatorsToDiscover = toLocatorsToDiscover
-                                             (initLookupsToStart,
+                                             (getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_GROUP);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class GroupsSetGroupsReplaceAll
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsAddNewDiscoveryChangeListener.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsAddNewDiscoveryChangeListener.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsAddNewDiscoveryChangeListener.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsAddNewDiscoveryChangeListener.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the <code>addDiscoveryListener</code> method, this class
@@ -55,14 +56,15 @@ public class LocsAddNewDiscoveryChangeLi
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        groupsToDiscover = toGroupsToDiscover(initLookupsToStart,
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        groupsToDiscover = toGroupsToDiscover(getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_LOC);
         locatorsToDiscover = toLocatorsToDiscover
-                                             (initLookupsToStart,
+                                             (getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_LOC);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class LocsAddNewDiscoveryChangeListener
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsAddNewDiscoveryListener.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsAddNewDiscoveryListener.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsAddNewDiscoveryListener.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsAddNewDiscoveryListener.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the <code>addDiscoveryListener</code> method, this class
@@ -54,13 +55,14 @@ public class LocsAddNewDiscoveryListener
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        groupsToDiscover = toGroupsToDiscover(initLookupsToStart,
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        groupsToDiscover = toGroupsToDiscover(getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_LOC);
         locatorsToDiscover = toLocatorsToDiscover
-                                             (initLookupsToStart,
+                                             (getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_LOC);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class LocsAddNewDiscoveryListener

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsDiscardUnreachable.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsDiscardUnreachable.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsDiscardUnreachable.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsDiscardUnreachable.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the <code>discard</code> method, this class verifies
@@ -56,14 +57,15 @@ public class LocsDiscardUnreachable exte
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        groupsToDiscover = toGroupsToDiscover(initLookupsToStart,
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        groupsToDiscover = toGroupsToDiscover(getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_LOC);
         locatorsToDiscover = toLocatorsToDiscover
-                                             (initLookupsToStart,
+                                             (getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_LOC);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class LocsDiscardUnreachable
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsDiscovered.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsDiscovered.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsDiscovered.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsDiscovered.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -53,13 +54,14 @@ public class LocsDiscovered extends Disc
      *
      *  Retrieves additional configuration values. 
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        groupsToDiscover = toGroupsToDiscover(initLookupsToStart,
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        groupsToDiscover = toGroupsToDiscover(getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_LOC);
-        locatorsToDiscover = toLocatorsToDiscover(initLookupsToStart,
+        locatorsToDiscover = toLocatorsToDiscover(getInitLookupsToStart(),
                                                   AbstractBaseTest.ALL_BY_LOC);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class LocsDiscovered
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsDiscoveredAll.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsDiscoveredAll.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsDiscoveredAll.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsDiscoveredAll.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -54,11 +55,12 @@ public class LocsDiscoveredAll extends D
      *
      *  Retrieves additional configuration values. 
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        locatorsToDiscover = toLocatorsToDiscover(initLookupsToStart,
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        locatorsToDiscover = toLocatorsToDiscover(getInitLookupsToStart(),
                                                   AbstractBaseTest.ALL_BY_LOC);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class LocsDiscoveredAll
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorChange.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorChange.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorChange.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorChange.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -50,13 +51,14 @@ public class LocsMulticastMonitorChange 
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        groupsToDiscover = toGroupsToDiscover(initLookupsToStart,
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        groupsToDiscover = toGroupsToDiscover(getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_LOC);
-        locatorsToDiscover = toLocatorsToDiscover(initLookupsToStart,
+        locatorsToDiscover = toLocatorsToDiscover(getInitLookupsToStart(),
                                                   AbstractBaseTest.ALL_BY_LOC);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class LocsMulticastMonitorChange
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorReplace.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorReplace.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorReplace.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorReplace.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -49,13 +50,14 @@ public class LocsMulticastMonitorReplace
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        groupsToDiscover = toGroupsToDiscover(initLookupsToStart,
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        groupsToDiscover = toGroupsToDiscover(getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_LOC);
-        locatorsToDiscover = toLocatorsToDiscover(initLookupsToStart,
+        locatorsToDiscover = toLocatorsToDiscover(getInitLookupsToStart(),
                                                   AbstractBaseTest.ALL_BY_LOC);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class LocsMulticastMonitorReplace
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorReplaceAll.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorReplaceAll.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorReplaceAll.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorReplaceAll.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -57,12 +58,13 @@ public class LocsMulticastMonitorReplace
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         /* discovering ALL_GROUPS - expect change event for all the lookups */
-        locatorsToDiscover = toLocatorsToDiscover(initLookupsToStart,
+        locatorsToDiscover = toLocatorsToDiscover(getInitLookupsToStart(),
                                                   AbstractBaseTest.ALL_BY_LOC);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class LocsMulticastMonitorReplaceAll
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorReplaceNone.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorReplaceNone.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorReplaceNone.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorReplaceNone.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -51,13 +52,14 @@ public class LocsMulticastMonitorReplace
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        groupsToDiscover = toGroupsToDiscover(initLookupsToStart,
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        groupsToDiscover = toGroupsToDiscover(getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_LOC);
-        locatorsToDiscover = toLocatorsToDiscover(initLookupsToStart,
+        locatorsToDiscover = toLocatorsToDiscover(getInitLookupsToStart(),
                                                   AbstractBaseTest.ALL_BY_LOC);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class LocsMulticastMonitorReplaceNone
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorStop.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorStop.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorStop.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorStop.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -65,13 +66,14 @@ public class LocsMulticastMonitorStop ex
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        groupsToDiscover = toGroupsToDiscover(initLookupsToStart,
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        groupsToDiscover = toGroupsToDiscover(getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_LOC);
-        locatorsToDiscover = toLocatorsToDiscover(initLookupsToStart,
+        locatorsToDiscover = toLocatorsToDiscover(getInitLookupsToStart(),
                                                   AbstractBaseTest.ALL_BY_LOC);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class LocsMulticastMonitorStop
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsMulticastMonitorTerminate.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -51,13 +52,14 @@ public class LocsMulticastMonitorTermina
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        groupsToDiscover = toGroupsToDiscover(initLookupsToStart,
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        groupsToDiscover = toGroupsToDiscover(getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_LOC);
-        locatorsToDiscover = toLocatorsToDiscover(initLookupsToStart,
+        locatorsToDiscover = toLocatorsToDiscover(getInitLookupsToStart(),
                                                   AbstractBaseTest.ALL_BY_LOC);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class MulticastMonitorTerminate
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsSetGroupsReplaceAll.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsSetGroupsReplaceAll.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsSetGroupsReplaceAll.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/LocsSetGroupsReplaceAll.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.discoverymanager;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the <code>setGroups</code> method, this class verifies
@@ -56,12 +57,13 @@ public class LocsSetGroupsReplaceAll ext
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
-        groupsToDiscover = toGroupsToDiscover(initLookupsToStart,
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
+        groupsToDiscover = toGroupsToDiscover(getInitLookupsToStart(),
                                               AbstractBaseTest.ALL_BY_LOC);
-        locatorsToDiscover = toLocatorsToDiscover(initLookupsToStart,
+        locatorsToDiscover = toLocatorsToDiscover(getInitLookupsToStart(),
                                                   AbstractBaseTest.ALL_BY_LOC);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class LocsSetGroupsReplaceAll

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorChange.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorChange.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorChange.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorChange.java Wed Jan  2 05:20:52 2013
@@ -22,6 +22,8 @@ import java.util.logging.Level;
 
 import java.util.ArrayList;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
+import java.util.List;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -54,10 +56,11 @@ public class MulticastMonitorChange exte
     /** Performs actions necessary to prepare for execution of the current
      *  test (refer to the description of this method in the parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         mainListener = new GroupChangeListener();
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>
@@ -83,7 +86,7 @@ public class MulticastMonitorChange exte
          */
         synchronized(mainListener) {
             /* Replace alternate groups to cause changed events */
-            ArrayList locGroupsPairList = replaceMemberGroups(true);
+            List locGroupsPairList = replaceMemberGroups(true);
             /* Set the expected changed event info */
             mainListener.setLookupsToDiscover(locGroupsPairList,
                                               locatorsToDiscover,

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorReplace.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorReplace.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorReplace.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorReplace.java Wed Jan  2 05:20:52 2013
@@ -20,8 +20,9 @@ package com.sun.jini.test.spec.discovery
 
 import java.util.logging.Level;
 
-import java.util.ArrayList;
+import java.util.List;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -53,10 +54,11 @@ public class MulticastMonitorReplace ext
     /** Performs actions necessary to prepare for execution of the current
      *  test (refer to the description of this method in the parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         mainListener = new GroupChangeListener();
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      *    <li> reconfigures the lookup discovery manager to discover some of
@@ -79,7 +81,7 @@ public class MulticastMonitorReplace ext
          */
         synchronized(mainListener) {
             /* Replace all groups to cause discarded/changed events */
-            ArrayList locGroupsPairList = replaceMemberGroups(false);
+            List locGroupsPairList = replaceMemberGroups(false);
             /* Set the expected changed event info */
             mainListener.setLookupsToDiscover(locGroupsPairList,
                                               locatorsToDiscover,

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorReplaceAll.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorReplaceAll.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorReplaceAll.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorReplaceAll.java Wed Jan  2 05:20:52 2013
@@ -22,6 +22,7 @@ import java.util.logging.Level;
 
 import net.jini.discovery.DiscoveryGroupManagement;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -62,10 +63,11 @@ public class MulticastMonitorReplaceAll 
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         groupsToDiscover = DiscoveryGroupManagement.ALL_GROUPS;
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class MulticastMonitorReplaceAll
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorReplaceNone.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorReplaceNone.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorReplaceNone.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorReplaceNone.java Wed Jan  2 05:20:52 2013
@@ -21,8 +21,9 @@ package com.sun.jini.test.spec.discovery
 import java.util.logging.Level;
 
 import net.jini.discovery.DiscoveryGroupManagement;
-import java.util.ArrayList;
+import java.util.List;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -55,10 +56,11 @@ public class MulticastMonitorReplaceNone
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         mainListener = new GroupChangeListener();
-    }//end setup
+        return this;
+    }//end construct
 
     public void run() throws Exception {
         super.run();
@@ -69,7 +71,7 @@ public class MulticastMonitorReplaceNone
          */
         synchronized(mainListener) {
             /* Replace all groups with NO_GROUPS to generate events */
-            ArrayList locGroupsPairList = replaceMemberGroups
+            List locGroupsPairList = replaceMemberGroups
                                       (DiscoveryGroupManagement.NO_GROUPS);
             /* Set the expected changed event info */
             mainListener.setLookupsToDiscover(locGroupsPairList,

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorStop.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorStop.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorStop.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorStop.java Wed Jan  2 05:20:52 2013
@@ -20,9 +20,10 @@ package com.sun.jini.test.spec.discovery
 
 import java.util.logging.Level;
 
-import java.util.ArrayList;
+import java.util.List;
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupDiscoveryManager</code> utility
@@ -72,10 +73,11 @@ public class MulticastMonitorStop extend
      *  completely away.
      */
 
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         mainListener = new GroupChangeListener();
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>
@@ -104,7 +106,7 @@ public class MulticastMonitorStop extend
         synchronized(mainListener) {
             stopAnnouncements();
             /* Replace current groups with new groups to cause discards */
-            ArrayList locGroupsPairList = replaceMemberGroups(false);
+            List locGroupsPairList = replaceMemberGroups(false);
             mainListener.setLookupsToDiscover(locGroupsPairList,
                                               locatorsToDiscover,
                                               groupsToDiscover);

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/MulticastMonitorTerminate.java Wed Jan  2 05:20:52 2013
@@ -20,7 +20,7 @@ package com.sun.jini.test.spec.discovery
 
 import java.util.logging.Level;
 
-import java.util.ArrayList;
+import java.util.List;
 import com.sun.jini.qa.harness.QAConfig;
 
 /**
@@ -80,8 +80,8 @@ public class MulticastMonitorTerminate e
              * both group and locator discovery are retrieved, and the
              * expected discard info is set for those lookups.
              */
-            ArrayList discoveredByGroupsList =
-                                    filterListByGroups(initLookupsToStart,
+            List discoveredByGroupsList =
+                                    filterListByGroups(getInitLookupsToStart(),
                                                        groupsToDiscover);
             mainListener.setDiscardEventInfo(discoveredByGroupsList);
         }//end sync(mainListener)

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/RemoveGroupsAll.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/RemoveGroupsAll.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/RemoveGroupsAll.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/RemoveGroupsAll.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.spec.discovery
 
 import java.util.Map;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the <code>removeGroups</code> method, this class verifies
@@ -57,9 +58,10 @@ public class RemoveGroupsAll extends Rem
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         alternateRemoval = false;
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class RemoveGroupsAll

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/RemoveGroupsSome.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/RemoveGroupsSome.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/RemoveGroupsSome.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/RemoveGroupsSome.java Wed Jan  2 05:20:52 2013
@@ -23,6 +23,7 @@ import java.util.logging.Level;
 import com.sun.jini.test.share.GroupsUtil;
 import net.jini.discovery.DiscoveryGroupManagement;
 import java.util.ArrayList;
+import java.util.List;
 import com.sun.jini.qa.harness.QAConfig;
 
 /**
@@ -76,7 +77,7 @@ public class RemoveGroupsSome extends Di
      */
     public void run() throws Exception {
         super.run();
-        setGroupsToRemove(initLookupsToStart,alternateRemoval);
+        setGroupsToRemove(getInitLookupsToStart(),alternateRemoval);
         /* Must sync on listener since Discovered/Discarded/Changed Map
          * will change as events arrive, and setLookupsToDiscover
          * examines the contents of those maps. So we don't want those
@@ -84,7 +85,7 @@ public class RemoveGroupsSome extends Di
          */
         synchronized(mainListener) {
             /* Set the expected discarded event info */
-            mainListener.setLookupsToDiscover(initLookupsToStart,
+            mainListener.setLookupsToDiscover(getInitLookupsToStart(),
                                               locatorsToDiscover,
                                               newGroupsToDiscover);
         }//end sync(mainListener)
@@ -106,12 +107,12 @@ public class RemoveGroupsSome extends Di
      *  invoked by the run() method. This method constructs the set of
      *  groups to remove from the lookup discovery manager.
      */
-    void setGroupsToRemove(ArrayList list, boolean alternate) {
-        ArrayList removeList = new ArrayList(11);
-        ArrayList newDiscoverList = new ArrayList(11);
+    void setGroupsToRemove(List list, boolean alternate) {
+        List removeList = new ArrayList(11);
+        List newDiscoverList = new ArrayList(11);
         for(int i=0;i<list.size();i++) {
             LocatorGroupsPair pair = (LocatorGroupsPair)list.get(i);
-            String[] curGroups = pair.groups;
+            String[] curGroups = pair.getGroups();
             if( (curGroups == null) || (curGroups.length == 0) ) continue;
             if( ((i%2) == 0) || !alternate ) {//index is even or removeAll
                 for(int j=0;j<curGroups.length;j++) {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/SetGroupsReplaceAll.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/SetGroupsReplaceAll.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/SetGroupsReplaceAll.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/SetGroupsReplaceAll.java Wed Jan  2 05:20:52 2013
@@ -20,6 +20,7 @@ package com.sun.jini.test.spec.discovery
 
 import java.util.Map;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the <code>setGroups</code> method, this class verifies
@@ -56,10 +57,11 @@ public class SetGroupsReplaceAll extends
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
         alternateReplacement = false;
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class SetGroupsReplaceAll
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/SetGroupsReplaceSome.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/SetGroupsReplaceSome.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/SetGroupsReplaceSome.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/SetGroupsReplaceSome.java Wed Jan  2 05:20:52 2013
@@ -24,6 +24,7 @@ import com.sun.jini.test.share.GroupsUti
 import net.jini.discovery.DiscoveryGroupManagement;
 import java.util.ArrayList;
 import com.sun.jini.qa.harness.QAConfig;
+import java.util.List;
 
 /**
  * With respect to the <code>setGroups</code> method, this class verifies
@@ -75,7 +76,7 @@ public class SetGroupsReplaceSome extend
      */
     public void run() throws Exception {
         super.run();
-        setNewGroups(initLookupsToStart,alternateReplacement);
+        setNewGroups(getInitLookupsToStart(),alternateReplacement);
         /* Must sync on listener since Discovered/Discarded/Changed Map
          * will change as events arrive, and setLookupsToDiscover
          * examines the contents of those maps. So we don't want those
@@ -83,7 +84,7 @@ public class SetGroupsReplaceSome extend
          */
         synchronized(mainListener) {
             /* Set the expected discarded event info */
-            mainListener.setLookupsToDiscover(initLookupsToStart,
+            mainListener.setLookupsToDiscover(getInitLookupsToStart(),
                                               locatorsToDiscover,
                                               newGroupsToDiscover);
         }//end sync(mainListener)
@@ -105,11 +106,11 @@ public class SetGroupsReplaceSome extend
      *  invoked by the run() method. This method constructs the new
      *  set of groups with which to re-configure the lookup discovery manager.
      */
-    void setNewGroups(ArrayList list, boolean alternate) {
-        ArrayList newDiscoverList = new ArrayList(11);
+    void setNewGroups(List list, boolean alternate) {
+        List newDiscoverList = new ArrayList(11);
         for(int i=0;i<list.size();i++) {
             LocatorGroupsPair pair = (LocatorGroupsPair)list.get(i);
-            String[] curGroups = pair.groups;
+            String[] curGroups = pair.getGroups();
             if( (curGroups == null) || (curGroups.length == 0) ) continue;
             if( ((i%2) == 0) || !alternate ) {//index is even or removeAll
                 for(int j=0;j<curGroups.length;j++) {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/AbstractBaseTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/AbstractBaseTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/AddLocatorsFullyQualified.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/AddLocatorsFullyQualified.java Wed Jan  2 05:20:52 2013
@@ -25,6 +25,7 @@ import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.test.share.GroupsUtil;
 import com.sun.jini.test.share.LocatorsUtil;
@@ -85,8 +86,8 @@ public class AddLocatorsFullyQualified e
     protected HashMap regInfoMap = registrationMap;
 
     /** Retrieves additional configuration values. */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
 //      debugFlag = true;
 //      displayOn = true;
         useDiscoveryList = useOnlyLocDiscovery;
@@ -123,7 +124,8 @@ public class AddLocatorsFullyQualified e
 	    }
             logger.log(Level.FINE, "locsToAdd["+i+"] = "+locsToAdd[i]);
         }//end loop
-    }//end setup
+        return this;
+    }//end construct
 
     public void run() throws Exception {
         logger.log(Level.FINE, "run()");
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/AbstractBaseTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/AbstractBaseTest.java Wed Jan  2 05:20:52 2013
@@ -25,6 +25,7 @@ import com.sun.jini.test.share.BaseQATes
 
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.discovery.DiscoveryManagement;
 import net.jini.discovery.DiscoveryGroupManagement;
@@ -36,6 +37,7 @@ import net.jini.core.lookup.ServiceRegis
 import java.io.IOException;
 import java.rmi.RemoteException;
 import java.util.ArrayList;
+import java.util.List;
 
 /**
  * This class is an abstract class that acts as the base class which
@@ -47,7 +49,7 @@ import java.util.ArrayList;
  * multicast request, and unicast request protocols on behalf of the
  * tests that sub-class this abstract class.
  * <p>
  * This class provides an implementation of the <code>setup</code> method
  * which performs standard functions related to the initialization of the
  * system state necessary to execute the test.
  *
@@ -100,8 +102,8 @@ abstract public class AbstractBaseTest e
      *         utility
      * </ul>
      */
-    public void setup(QAConfig config) throws Exception {
-        super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+        super.construct(config);
 	/* Start group and locator discovery by creating a lookup 
 	 * discovery  manager.
 	 */
@@ -117,6 +119,7 @@ abstract public class AbstractBaseTest e
 				       config.getConfiguration());
 	ldmList.add(discoveryMgr);
 	mainListener = new LookupListener();
+        return this;
     }
 
     /** Executes the current test
@@ -165,7 +168,7 @@ abstract public class AbstractBaseTest e
      *  </ul>
      *  @throws com.sun.jini.qa.harness.TestException
      */
-    protected void doDiscovery(ArrayList locGroupsListStartedLookups,
+    protected void doDiscovery(List locGroupsListStartedLookups,
                                LookupDiscoveryManager ldm,
                                LookupListener listener,
                                LookupLocator[] locsToDiscover,
@@ -205,12 +208,12 @@ abstract public class AbstractBaseTest e
 
     /** Convenience method that encapsulates basic discovery processing.
      *  Use this method when a lookup discovery manager different from
      *  the standard one created during setup is to be used for discovery,
      *  and you know the row from the static discoverBy matrix to use when
      *  determining the lookups to discover by group, by locator, and by both.
      *  @throws com.sun.jini.qa.harness.TestException
      */
-    protected void doDiscovery(ArrayList locGroupsListStartedLookups,
+    protected void doDiscovery(List locGroupsListStartedLookups,
                                LookupDiscoveryManager ldm,
                                LookupListener listener,
                                int discoverByRow) throws TestException,
@@ -227,7 +230,7 @@ abstract public class AbstractBaseTest e
 
     /** Convenience method that encapsulates basic discovery processing.
      *  Use this method when the standard lookup discovery manager
      *  created during setup is to be used for discovery, and you know
      *  the row from the static discoverBy matrix to use when determining
      *  the lookups to discover by group, by locator, and by both.
      *  @throws com.sun.jini.qa.harness.TestException
@@ -254,16 +257,16 @@ abstract public class AbstractBaseTest e
      *  mechanism(s) (group, locator or both) are to be used to discover
      *  the corresponding lookup service.
      */
-    public static LookupLocator[] toLocatorsToDiscover(ArrayList list,
+    public static LookupLocator[] toLocatorsToDiscover(List list,
                                                        int discoverByRow)
     {
-        ArrayList locList = new ArrayList(list.size());
+        List locList = new ArrayList(list.size());
         for(int i=0;i<list.size();i++) {
             LocatorGroupsPair pair = (LocatorGroupsPair)list.get(i);
             if(    (discoverBy[discoverByRow][i] == BY_BOTH)
                 || (discoverBy[discoverByRow][i] == BY_LOC) )
             {
-                locList.add(pair.locator);
+                locList.add(pair.getLocator());
             }//endif
         }//end loop
         return 
@@ -279,13 +282,13 @@ abstract public class AbstractBaseTest e
      *  mechanism(s) (group, locator or both) are to be used to discover
      *  the corresponding lookup service.
      */
-    public static String[] toGroupsToDiscover(ArrayList list,
+    public static String[] toGroupsToDiscover(List list,
                                               int discoverByRow)
     {
-        ArrayList groupsList = new ArrayList(11);
+        List groupsList = new ArrayList(11);
         for(int i=0;i<list.size();i++) {
             LocatorGroupsPair pair = (LocatorGroupsPair)list.get(i);
-            String[] curGroups = pair.groups;
+            String[] curGroups = pair.getGroups();
             if(curGroups.length == 0) continue;//skip NO_GROUPS
             if(    (discoverBy[discoverByRow][i] == BY_BOTH)
                 || (discoverBy[discoverByRow][i] == BY_GROUP) )
@@ -47,7 +49,7 @@ import java.util.ArrayList;
  * tests that sub-class this abstract class.
  * <p>
- * This class provides an implementation of the <code>setup</code> method
+ * This class provides an implementation of the <code>construct</code> method
  * which performs standard functions related to the initialization of the
  * system state necessary to execute the test.
@@ -205,12 +208,12 @@ abstract public class AbstractBaseTest e
     /** Convenience method that encapsulates basic discovery processing.
      *  Use this method when a lookup discovery manager different from
-     *  the standard one created during setup is to be used for discovery,
+     *  the standard one created during construct is to be used for discovery,
      *  and you know the row from the static discoverBy matrix to use when
      *  determining the lookups to discover by group, by locator, and by both.
@@ -227,7 +230,7 @@ abstract public class AbstractBaseTest e
     /** Convenience method that encapsulates basic discovery processing.
      *  Use this method when the standard lookup discovery manager
-     *  created during setup is to be used for discovery, and you know
+     *  created during construct is to be used for discovery, and you know
      *  the row from the static discoverBy matrix to use when determining
      *  the lookups to discover by group, by locator, and by both.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/AddNewDiscoveryChangeListener.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoverymanager/AddNewDiscoveryChangeListener.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/AbstractBaseTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/AbstractBaseTest.java Wed Jan  2 05:20:52 2013
@@ -21,7 +21,7 @@ package com.sun.jini.test.spec.discovery
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import com.sun.jini.qa.harness.TestException;
 import com.sun.jini.qa.harness.QAConfig;
 import com.sun.jini.qa.harness.TestException;
@@ -85,6 +85,7 @@ import net.jini.security.TrustVerifier;
 import net.jini.security.proxytrust.ServerProxyTrust;
 
 import com.sun.jini.proxy.BasicProxyTrustVerifier;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class is an abstract class that acts as the base class which
@@ -96,7 +97,7 @@ import com.sun.jini.proxy.BasicProxyTrus
  * or locator discovery on behalf of the tests that sub-class this
  * abstract class.
  * <p>
  * This class provides an implementation of the <code>setup</code> method
  * which performs standard functions related to the initialization of the
  * system state necessary to execute the test.
  *
@@ -105,9 +106,9 @@ import com.sun.jini.proxy.BasicProxyTrus
  * be executed in order to verify the assertions addressed by that test.
  * 
  * @see com.sun.jini.qa.harness.QAConfig
- * @see com.sun.jini.qa.harness.QATest
+ * @see com.sun.jini.qa.harness.QATestEnvironment
  */
-abstract public class AbstractBaseTest extends QATest {
+abstract public class AbstractBaseTest extends QATestEnvironment implements Test {
 
     protected boolean debugFlag = false;//resets timeouts for faster completion
     protected boolean displayOn = false;//verbose in waitForDiscovery/Discard
@@ -835,8 +836,8 @@ abstract public class AbstractBaseTest e
      *     <li> starts the configured number of lookup services
      *   </ul>
      */
-    public void setup(QAConfig config) throws Exception {
-	super.setup(config);
+    public Test construct(QAConfig config) throws Exception {
+	super.construct(config);
 	logger.entering("","setup");
 	getSetupInfo();
 	getLookupInfo();
@@ -848,8 +849,9 @@ abstract public class AbstractBaseTest e
 		   +"service configured to join NO_GROUPS and NO_LOCATORS");
 	// returned proxy is already prepared
 	discoverySrvc = 
-	    (LookupDiscoveryService)(manager.startService(serviceName));
-    }//end setup
+	    (LookupDiscoveryService)(getManager().startService(serviceName));
+        return this;
+    }//end construct
 
     /** Executes the current test
      */
@@ -903,7 +905,7 @@ abstract public class AbstractBaseTest e
     /** Convenience method that can be used to start, at a single point 
      *  during the current test run, all of the lookup services needed by
      *  that test run. Useful when all of the lookup services are to be
      *  started during setup processing.
      */
     protected void startAllLookups() throws Exception {
         int totalNLookups = nLookupServices+nAddLookupServices;
@@ -946,12 +948,12 @@ abstract public class AbstractBaseTest e
         {
             /* Use either a random or an explicit locator port */
             DiscoveryProtocolSimulator generator = 
-		new DiscoveryProtocolSimulator(config, memberGroups, manager, port);
+		new DiscoveryProtocolSimulator(getConfig(), memberGroups, getManager(), port);
             genMap.put( generator, memberGroups );
             lookupProxy = generator.getLookupProxy();
         } else {//start a non-simulated lookup service implementation
 	    logger.log(Level.FINER, "Starting lookup for host " + serviceHost);
-            lookupProxy = manager.startLookupService(serviceHost); // already prepared 
+            lookupProxy = getManager().startLookupService(serviceHost); // already prepared 
             genMap.put( lookupProxy, memberGroups );
         }//endif
         lookupList.add( lookupProxy );
@@ -1219,7 +1221,7 @@ abstract public class AbstractBaseTest e
 					    mHandback,
 					    leaseDuration);	
 	    logger.log(Level.FINEST, "Preparing fiddler registration");
-	    Configuration c = config.getConfiguration();
+	    Configuration c = getConfig().getConfiguration();
 	    ProxyPreparer p = new BasicProxyPreparer();
 	    if (c instanceof com.sun.jini.qa.harness.QAConfiguration) {
 		  p = (ProxyPreparer) c.getEntry("test", 
@@ -2139,7 +2141,7 @@ abstract public class AbstractBaseTest e
 
     /** Common code, shared by this class and its sub-classes, that is 
      *  invoked by the run() method. This will method will replace the
      *  member groups of each lookup service started during setup. How
      *  those groups are replaced is dependent on the values of the input
      *  parameters. 
      * 
@@ -2426,7 +2428,7 @@ abstract public class AbstractBaseTest e
 	    port = 4160;
 	}
 	String hostname = 
-	    config.getServiceHost("net.jini.core.lookup.ServiceRegistrar", indx, null);
+	    getConfig().getServiceHost("net.jini.core.lookup.ServiceRegistrar", indx, null);
 	if (hostname == null) {
 	    hostname = "localhost";
 	    try {
@@ -2449,8 +2451,8 @@ abstract public class AbstractBaseTest e
             String groupsArg = getConfig().getServiceStringProperty
                                     ("net.jini.core.lookup.ServiceRegistrar",
                                      "membergroups", i);
-            String uniqueGroupsArg = config.makeGroupsUnique(groupsArg);
-            String[] memberGroups = config.parseString(uniqueGroupsArg,",");
+            String uniqueGroupsArg = getConfig().makeGroupsUnique(groupsArg);
+            String[] memberGroups = getConfig().parseString(uniqueGroupsArg,",");
             if(memberGroups == DiscoveryGroupManagement.ALL_GROUPS) continue;
             memberGroupsList.add(memberGroups);
             /*Constrained Locator for lookup service i */
@@ -2659,7 +2661,7 @@ abstract public class AbstractBaseTest e
     protected Lease getPreparedLease(LookupDiscoveryRegistration reg) 
 	throws RemoteException
     {
-	Configuration c = config.getConfiguration();
+	Configuration c = getConfig().getConfiguration();
 	if (!(c instanceof com.sun.jini.qa.harness.QAConfiguration)) { // if none configuration
 	    return reg.getLease();
 	}
@@ -96,7 +97,7 @@ import com.sun.jini.proxy.BasicProxyTrus
  * abstract class.
  * <p>
- * This class provides an implementation of the <code>setup</code> method
+ * This class provides an implementation of the <code>construct</code> method
  * which performs standard functions related to the initialization of the
  * system state necessary to execute the test.
@@ -903,7 +905,7 @@ abstract public class AbstractBaseTest e
      *  during the current test run, all of the lookup services needed by
      *  that test run. Useful when all of the lookup services are to be
-     *  started during setup processing.
+     *  started during construct processing.
      */
     protected void startAllLookups() throws Exception {
@@ -2139,7 +2141,7 @@ abstract public class AbstractBaseTest e
     /** Common code, shared by this class and its sub-classes, that is 
      *  invoked by the run() method. This will method will replace the
-     *  member groups of each lookup service started during setup. How
+     *  member groups of each lookup service started during construct. How
      *  those groups are replaced is dependent on the values of the input
      *  parameters. 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/AddLocatorsFullyQualified.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/discoveryservice/event/AddLocatorsFullyQualified.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================